%
%ana_wave.m
%
% Funcion para realizar la transformada wavelet de la seal de estudio
%
%Parametros de entrada :
%          irele     : seal de estudio
%          ejes_wave, ejes_detalle,ejes_cri,ejes_fourier : ubicacion de ventanas
%          tipo_w    : nombre de wavelet
%          nro_w     : tipo de wavelet
%          nro_nivel : nivel de descomposicion
%          xw, yw    : ubicacion (x,y) de la ventana de resultados
%          t         : Intervalo de tiempo considerado
%
%Parametros de salida :
%          ejes_wave, ejes_detalle, ejes_cri, ejes_fourier : ubicacion de ventanas
%                                                        d : Detalles del analisis wavelet
%
% obs:
%     Se utiliza el toolbox de wavelet de Matlab.
%
function [ejes_wave, ejes_detalle,ejes_cri,ejes_fourier,d]=ana_wave(irele,ejes_wave,...
    ejes_detalle,ejes_cri,ejes_fourier,tipo_w,nro_w,nro_nivel,xw,yw,t);

for i=1:length(ejes_wave)
   set(ejes_wave(i),'Visible','off');
   axes(ejes_wave(i));
   cla;
end
set(ejes_detalle,'Visible','off');
axes(ejes_detalle);
cla;
set(ejes_cri,'Visible','off');
axes(ejes_cri);
cla;
set(ejes_fourier,'Visible','off');
axes(ejes_fourier);
cla;

switch nro_nivel
case {1,2,3}
   tamano=10;
case {4,5,6}   
   tamano=8;
case {7,8,9,10}
   tamano=7;
end

switch tipo_w
case 1
    tipo_w='db';
    tipo=[tipo_w,int2str(nro_w)];
case 2
    tipo_w='haar';
    tipo=tipo_w;
case 3
    tipo_w='sym';
    tipo=[tipo_w,int2str(nro_w)];
end
d=[];
[c,l] = wavedec(irele,nro_nivel,tipo);
for i=1:nro_nivel
 cd=wrcoef('d',c,l,tipo,i);
  d=[d;cd];
end
a=wrcoef('a',c,l,tipo,nro_nivel);
figura=[d;a];
altura_eje=0.78*yw/(nro_nivel+1);
Yeje=yw*0.17;
rotulod=char('d1','d2', 'd3','d4','d5','d6','d7','d8','d9','d10');
rotuloa=char('a1','a2','a3','a4','a5','a6','a7','a8','a9','a10');
%
%Pinta en pantalla el resultado del analisis de la DWT de la seal
%
for i=1:(nro_nivel+1)
 ejes_wave(i) = axes('units','pixels','Position',[xw/3-30 Yeje xw/3+30 altura_eje*0.6]);
 Yeje=Yeje+altura_eje;
 axes(ejes_wave(i));
 set(gcf,'currentaxes',ejes_wave(i));
 plot(t,figura(i,:),'b');
 if i==1
    xlabel('[seg.]','HorizontalAlignment','left');
 end
 axis on;
 set(ejes_wave(i),'fontsize',tamano,'linewidth',1);
 if i==nro_nivel+1
   title(rotuloa(i-1,:),'fontweight','bold');
 else
    title(rotulod(i,:),'fontweight','bold');
 end
 zoom
end
ejes_detalle = axes('units','pixels','Position',[(2/3)*xw+45 yw*0.65 0.28*xw 0.26*yw]);
axes(ejes_detalle);
set(gcf,'currentaxes',ejes_detalle);
plot(t,figura(1,:),'r'); 
hold on
set(ejes_detalle,'fontsize',9,'linewidth',1);
xlabel('[seg.]','HorizontalAlignment','left');
title('d1: detalle de discriminacion del rele','fontweight','bold','fontsize',10);
 